@@ -1421,122 +1421,3 @@ extractAIC.earth <- function(fit, scale = 0, k = 2, warn=TRUE, ...)
     nterms <- length(fit$selected.terms)
     c(effective.nbr.of.params(nterms, get.nknots(nterms), fit$penalty), fit$gcv)
 }
-
-#-----------------------------------------------------------------------------
-# Method functions for plotmo.R
-
-# get.singles.earth and get.pairs.earth exist because we need to look at
-# the built earth model to determine singles and pairs, because:
-#
-# (i)  get.singles.default and get.pairs.default return ALL singles and
-#      pairs, even if unused
-#
-# (ii) earth CREATES pairs,  whereas lm will only have pairs if forms such
-#      as x1:x2 of x1*x2 appear in the formula
-
-get.singles.earth <- function(object, x, degree1, pred.names, trace)
-{
-    dataClasses <- attr(object$terms, "dataClasses")
-    if(is.character(degree1) && !is.na(pmatch(degree1, "all"))) {
-        # user wants all used predictors
-        used.vars <- NULL
-        selected <- object$selected.terms[reorder.earth(object, decomp="anova")]
-        if(length(selected) > 0)
-            used.vars <- unique(
-                        which(object$dirs[selected, , drop=FALSE] != 0, arr.ind=TRUE)[,2])
-        return(used.vars)
-    }
-    check.classname(object, deparse(substitute(object)), "earth")
-    if(any((dataClasses == "factor") | (dataClasses == "ordered"))) {
-        # NOV 2008: new code, only use if factors in x
-        # TODO this can give extra predictors if variable names alias
-        #      e.g. "x" and "x1" are both variable names
-        used.colnames <- apply(object$dirs, 2, any1)
-        colnames <- colnames(object$dirs)[used.colnames]
-        used.preds <- NULL
-        for(ipred in seq_along(object$namesx.org)) {
-            if(is.factor(x[,ipred])) {
-                # This knows how to deal with expanded factor names because
-                # it e.g. looks for "^pclass" in "pclass3rd"
-                if(length(grep(paste("^", object$namesx.org[ipred], sep=""), colnames)) > 0)
-                    used.preds <- c(used.preds, ipred)
-            } else {
-                # exact match
-                if(length(grep(paste("^", object$namesx.org[ipred], "$", sep=""), colnames)) > 0)
-                    used.preds <- c(used.preds, ipred)
-                used.preds <- c(used.preds, ipred)
-            }
-        }
-        Singles <- unique(used.preds)
-    } else {
-        # original code, use if no factors in x
-        Singles <- NULL
-        selected <- object$selected.terms[  # selected is all degree 1 terms
-                        reorder.earth(object, decomp="anova", degree=1, min.degree=1)]
-        if(length(selected) > 0)
-            Singles <- unique(
-                        which(object$dirs[selected, , drop=FALSE] != 0, arr.ind=TRUE)[,2])
-    }
-    if(length(Singles) == 0 && is.specified(degree1))
-        warning1("\"degree1\" specified but no degree1 plots")
-    if(length(Singles) > 0) {
-        check.index.vec("degree1", degree1, Singles)
-        Singles <- Singles[degree1]
-    }
-    Singles # Singles is a vector of indices of predictors for degree1 plots
-
-}
-
-get.pairs.earth <- function(object, x, degree2, pred.names, trace=FALSE)
-{
-    if(is.character(degree2) && !is.na(pmatch(degree2, "all"))) {
-        # user wants all combos of all used predictors
-        used.vars <- NULL
-        selected <- object$selected.terms[reorder.earth(object, decomp="anova")]
-        if(length(selected) > 0)
-            used.vars <- unique(
-                        which(object$dirs[selected, , drop=FALSE] != 0, arr.ind=TRUE)[,2])
-        if(length(used.vars) == 0)
-            return(matrix(0, nrow=0, ncol=2)) # no pairs
-        col1 <- rep(used.vars, times=length(used.vars))
-        col2 <- rep(used.vars, each=length(used.vars))
-        Pairs <- cbind(col1, col2)
-        Pairs <- Pairs[col1 != col2, , drop=FALSE]
-        return(unique(t(apply(Pairs, 1, sort)))) # remove duplicate pairs
-    }
-    Pairs <- matrix(0, nrow=0, ncol=2)      # no pairs
-    selected <- object$selected.terms[      # selected is all degree 2 terms
-                    reorder.earth(object, decomp="anova", degree=2, min.degree=2)]
-    Pairs <- vector(mode="numeric")
-    for(i in selected)                      # append indices of the two preds in term i
-        Pairs <- c(Pairs, which(object$dirs[i,] != 0))
-    Pairs <- unique(matrix(Pairs, ncol=2, byrow=TRUE))
-    if(nrow(Pairs) == 0 && is.specified(degree2))
-        warning1("\"degree2\" specified but no degree2 plots")
-    if(nrow(Pairs) > 0) { # any pairs?
-        check.index.vec("degree2", degree2, Pairs)
-        Pairs <- Pairs[degree2, , drop=FALSE]
-        if(nrow(Pairs) && any(sapply(x, is.factor))) { # any columns in x are factors?
-            # Pairs works off expanded factor names, so replace each name with
-            # with index of original variable name
-            # TODO this can give wrong results if variable names alias
-            #      e.g. if "x" and "x1" are both variable names
-            #      this takes the LAST of the matching names so correct with "x" "x1" but not "x1" "x"
-            dir.colnames <- colnames(object$dirs)
-            prednames <- object$namesx.org
-            prednames.hat <- paste("^", prednames, sep="")
-            for(i in 1:nrow(Pairs))
-                for(j in 1:2) {
-                    ipred1 <- 0
-                    for(ipred in seq_along(prednames.hat))
-                        if(length(grep(prednames.hat[ipred], dir.colnames[Pairs[i, j]])) > 0)
-                            ipred1 <- ipred
-                    if(ipred1 == 0)
-                        stop1("internal error: illegal ipred1 in get.pairs.earth")
-                    Pairs[i, j] <- ipred1
-                }
-            Pairs <- unique(Pairs)  # unique is needed if multiple factors were converted to single predictor
-        }
-    }
-    Pairs
-}
